@@ -174,7 +174,7 @@ class TypeBase:
         self.value: int = value
 
         if self.value not in self.values:
-            raise AttributeError(f"invalid value: {value}")
+            self.values[self.value] = "UNKNOWN_TYPE"
 
     def __str__(self) -> str:
         return self.values[self.value]
